pub enum Mamba3Cache {
DoubleSsd(Mamba3DoubleSsdCache),
SingleSsd(Mamba3SingleSsdCache),
}Expand description
A pathway-tagged bundle of per-block cache, so a single dispatch entry can accept / return either cache family.
The cache selection infers whether Double-SSD or Single-SSD is used.
If none is specified, this defaults to Self::SingleSsd.
See also crate::mamba3::ssd_path::Mamba3SsdPath.
Variants
DoubleSsd(Mamba3DoubleSsdCache)
Caches for double-ssd pathway.
SingleSsd(Mamba3SingleSsdCache)
Caches for single-ssd pathway.
Implementations
Sourceimpl Mamba3Cache
impl Mamba3Cache
Sourcepub fn double_ssd(self) -> Option<Mamba3DoubleSsdCache>
pub fn double_ssd(self) -> Option<Mamba3DoubleSsdCache>
Unwrap to the double-SSD cache, or None if this is the single-SSD variant.
Sourcepub fn single_ssd(self) -> Option<Mamba3SingleSsdCache>
pub fn single_ssd(self) -> Option<Mamba3SingleSsdCache>
Unwrap to the single-SSD cache, or None if this is the double-SSD variant.