pub struct MseLoss;Expand description
Calculate the mean squared error loss from the input logits and the targets.
Implementations
Sourceimpl MseLoss
impl MseLoss
Sourcepub fn forward(
&self,
logits: Tensor<2>,
targets: Tensor<2>,
reduction: Reduction,
) -> Tensor<1>
pub fn forward( &self, logits: Tensor<2>, targets: Tensor<2>, reduction: Reduction, ) -> Tensor<1>
Compute the criterion on the input tensor.
Shapes
- logits:
[batch_size, num_targets] - targets:
[batch_size, num_targets]
Sourcepub fn forward_no_reduction<const D: usize>(
&self,
logits: Tensor<D>,
targets: Tensor<D>,
) -> Tensor<D>
pub fn forward_no_reduction<const D: usize>( &self, logits: Tensor<D>, targets: Tensor<D>, ) -> Tensor<D>
Compute the criterion on the input tensor without reducing.