ClassLatent

Enum ClassLatent 

pub enum ClassLatent {
    Start,
    Middle,
    End,
    Custom(usize),
}
Position marker for a learnable class latent inserted into a layer’s working sequence (embedding width = d_model).

Variants



Start

Prepend before the whole sequence (index 0).



Middle

Insert at the middle of the original sequence (index L/2). Incompatible with step() calls.



End

Append after the whole sequence (index L). Incompatible with step() calls.



Custom(usize)

Insert at an explicit index into the original sequence.