pub enum ClassToken {
Start,
Middle,
End,
Custom(usize),
}Expand description
Position marker for a learnable class token inserted into a network’s input sequence (embedding width = the network input width / “d_input”).
Variants
Start
Prepend before the whole sequence (index 0).
Middle
Insert at the middle of the original sequence (index L/2).
Incompatible with step() calls.
End
Append after the whole sequence (index L).
Incompatible with step() calls.
Custom(usize)
Insert at an explicit index into the original sequence.