pub struct BinaryCrossEntropyLossConfig {
pub logits: bool,
}Expand description
Configuration to create a Binary Cross-entropy loss using the init function.
Fields
logits: boolTreat the inputs as logits, applying a sigmoid activation when computing the loss.
Implementations
Sourceimpl BinaryCrossEntropyLossConfig
impl BinaryCrossEntropyLossConfig
Sourcepub fn with_logits(self, logits: bool) -> Self
pub fn with_logits(self, logits: bool) -> Self
Sets the value for the field logits.
Treat the inputs as logits, applying a sigmoid activation when computing the loss.
- Defaults to
false
Sourceimpl BinaryCrossEntropyLossConfig
impl BinaryCrossEntropyLossConfig
Sourcepub fn init(&self) -> BinaryCrossEntropyLoss
pub fn init(&self) -> BinaryCrossEntropyLoss
Initialize Binary Cross-entropy loss.