pub struct MseLoss;Expand description
Calculate the mean squared error loss from the input logits and the targets.
Implementations
Sourceimpl MseLoss
impl MseLoss
Sourcepub fn forward<B: Backend>(
&self,
logits: Tensor<B, 2>,
targets: Tensor<B, 2>,
reduction: Reduction,
) -> Tensor<B, 1>
pub fn forward<B: Backend>( &self, logits: Tensor<B, 2>, targets: Tensor<B, 2>, reduction: Reduction, ) -> Tensor<B, 1>
Compute the criterion on the input tensor.
Shapes
- logits: [batch_size, num_targets]
- targets: [batch_size, num_targets]
Sourcepub fn forward_no_reduction<const D: usize, B: Backend>(
&self,
logits: Tensor<B, D>,
targets: Tensor<B, D>,
) -> Tensor<B, D>
pub fn forward_no_reduction<const D: usize, B: Backend>( &self, logits: Tensor<B, D>, targets: Tensor<B, D>, ) -> Tensor<B, D>
Compute the criterion on the input tensor without reducing.