pub struct RmsNormGated<B: Backend> {
pub gamma: Param<Tensor<B, 1>>,
pub norm_before_gate: bool,
}Expand description
Applies Gated Rms Normalization over an input tensor along the last dimension.
- If
norm_before_gate=true:Y = (X / sqrt(mean(X^2) + eps) * gamma) * SiLU(z) - If
norm_before_gate=false:Y = (X * SiLU(z)) / sqrt(mean((X * SiLU(z))^2) + eps) * gamma
Where:
Xis the input tensorYis the output tensorzis the gating tensorgammais the learnable weightmeanis the mean operationepsis a small value to avoid division by zero.
Should be created using the RmsNormGatedConfig configuration.
Fields
gamma: Param<Tensor<B, 1>>The learnable parameter to scale the normalized tensor.
norm_before_gate: boolWhether to normalize before applying the gating.
Implementations