pub struct ConstantLr {
pub lr: f64,
}Expand description
Constant Learning Rate Scheduler.
Simply returns a fixed learning rate for all steps. Useful for simple experiments or when learning rate scheduling is not needed.
Fields
lr: f64Implementations
Sourceimpl ConstantLr
impl ConstantLr
Sourceimpl ConstantLr
impl ConstantLr