pub struct Mamba2CachesConfig {
pub n_real_caches: usize,
pub cache: Mamba2CacheConfig,
}Expand description
Configuration / factory for Mamba2Caches.
Fields
n_real_caches: usizeNumber of cache slots. Equals the number of virtual layers in the network (one cache per layer, even when layers share weights).
cache: Mamba2CacheConfigShared configuration that determines the shape of each individual cache tensor.
Implementations
Sourceimpl Mamba2CachesConfig
impl Mamba2CachesConfig
Sourcepub fn new(n_real_caches: usize, cache: Mamba2CacheConfig) -> Self
pub fn new(n_real_caches: usize, cache: Mamba2CacheConfig) -> Self
Sourceimpl Mamba2CachesConfig
impl Mamba2CachesConfig
Sourcepub fn new_from_block_config(
n_real_caches: usize,
batch: usize,
block_config: Mamba2Config,
) -> Self
pub fn new_from_block_config( n_real_caches: usize, batch: usize, block_config: Mamba2Config, ) -> Self
Convenience constructor that derives cache shapes directly from a
Mamba2Config block configuration.
Sourcepub fn init<B: Backend>(&self, device: &B::Device) -> Mamba2Caches<B>
pub fn init<B: Backend>(&self, device: &B::Device) -> Mamba2Caches<B>
Allocate all cache tensors (zero-initialised) on device.